@@ -1,28 +1,12 @@
 use v5.26;
 use Object::Pad ':experimental(init_expr)';
+# ABSTRACT: Ethereum transaction abstraction
 
-package Blockchain::Ethereum::Transaction 0.008;
+package Blockchain::Ethereum::Transaction;
 role Blockchain::Ethereum::Transaction;
 
-=encoding utf8
-
-=head1 NAME
-
-Blockchain::Ethereum::Transaction - Ethereum transaction abstraction
-
-=head1 SYNOPSIS
-
-In most cases you don't want to use this directly, use instead:
-
-=over 4
-
-=item * B<Legacy>: L<Blockchain::Ethereum::Transaction::Legacy>
-
-=item * B<EIP1559>: L<Blockchain::Ethereum::Transaction::EIP1559>
-
-=back
-
-=cut
+our $AUTHORITY = 'cpan:REFECO';    # AUTHORITY
+our $VERSION   = '0.009';          # VERSION
 
 use Carp;
 use Crypt::Digest::Keccak256 qw(keccak256);
@@ -41,60 +25,10 @@ field $s :reader :writer :param = undef;
 
 field $rlp :reader = Blockchain::Ethereum::RLP->new();
 
-=head2 serialize
-
-To be implemented by the child classes, encodes the given transaction parameters to RLP
-
-Usage:
-
-    serialize() -> RLP encoded transaction bytes
-
-=over 4
-
-=back
-
-Returns the RLP encoded transaction bytes
-
-=cut
-
 method serialize;
 
-=head2 generate_v
-
-Generate the transaction v field using the given y-parity
-
-Usage:
-
-    generate_v($y_parity) -> hexadecimal v
-
-=over 4
-
-=item * C<$y_parity> y-parity
-
-=back
-
-Returns the v hexadecimal value also sets the v fields from transaction
-
-=cut
-
 method generate_v;
 
-=head2 hash
-
-SHA3 Hash the serialized transaction object
-
-Usage:
-
-    hash() -> SHA3 transaction hash
-
-=over 4
-
-=back
-
-Returns the SHA3 transaction hash bytes
-
-=cut
-
 method hash {
 
     return keccak256($self->serialize);
@@ -110,20 +44,104 @@ method _equalize_params ($params) {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Blockchain::Ethereum::Transaction - Ethereum transaction abstraction
+
+=head1 VERSION
+
+version 0.009
+
+=head1 SYNOPSIS
+
+Ethereum transaction abstraction for signing and generating raw transactions
+
+    # parameters can be hexadecimal strings or Math::BigInt instances
+    my $transaction = Blockchain::Ethereum::Transaction::EIP1559->new(
+        nonce                    => '0x0',
+        max_fee_per_gas          => '0x9',
+        max_priority_fee_per_gas => '0x0',
+        gas_limit                => '0x1DE2B9',
+        to                       => '0x3535353535353535353535353535353535353535'
+        value                    => Math::BigInt->new('1000000000000000000'),
+        data                     => '0x',
+        chain_id                 => '0x539'
+    );
+
+    # github.com/refeco/perl-ethereum-keystore
+    my $key = Blockchain::Ethereum::Keystore::Key->new(
+        private_key => pack "H*",
+        '4646464646464646464646464646464646464646464646464646464646464646'
+    );
+
+    $key->sign_transaction($transaction);
+
+    my $raw_transaction = $transaction->serialize;
+
+    print unpack("H*", $raw_transaction);
+
+Standalone version:
+
+    ethereum-raw-tx --tx-type=legacy --chain-id=0x1 --nonce=0x9 --gas-price=0x4A817C800 --gas-limit=0x5208 --to=0x3535353535353535353535353535353535353535 --value=0xDE0B6B3A7640000 --pk=0x4646464646464646464646464646464646464646464646464646464646464646
+
+Supported transaction types:
+
+=over 4
+
+=item * B<Legacy>
+
+=item * B<EIP1559 Fee Market>
+
+=back
+
+=head1 METHODS
+
+=head2 serialize
+
+To be implemented by the child classes, encodes the given transaction parameters to RLP
+
+=over 4
+
+=back
+
+Returns the RLP encoded transaction bytes
+
+=head2 generate_v
+
+Generate the transaction v field using the given y-parity
+
+=over 4
+
+=item * C<$y_parity> y-parity
+
+=back
+
+Returns the v hexadecimal value also sets the v fields from transaction
+
+=head2 hash
+
+SHA3 Hash the serialized transaction object
+
+=over 4
+
+=back
+
+Returns the SHA3 transaction hash bytes
+
 =head1 AUTHOR
 
-Reginaldo Costa, C<< <refeco at cpan.org> >>
+Reginaldo Costa <refeco@cpan.org>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to L<https://github.com/refeco/perl-ethereum-transaction>
-
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2023 by REFECO.
 
 This is free software, licensed under:
 
-  The MIT License
+  The MIT (X11) License
 
 =cut
